@@ -9,6 +9,15 @@ import schedlib as s
 import matplotlib
 matplotlib.use("Qt5Agg")
 
+# in matplotlib version 3.3 the internal epoch was changed from year 1 to 1970
+# this epoch is used to convert dates to floating points internally
+# unfortunately that internal representation leaks to axis.get_xlim
+# so set the epoch to the old version here to get consistent behaviour with
+# both version (<3.3 and >=3.3)
+from distutils.version import LooseVersion
+if LooseVersion(matplotlib.__version__) >= LooseVersion("3.3"):
+    matplotlib.rcParams["date.epoch"] = "0000-12-31T00:00:00"
+
 # import function to improve toolbar, but might not be available on all systems
 try:
     from .plot_toolbar import adjust as adjust_toolbar
@@ -723,7 +732,7 @@ class BeamWidget(QWidget):
                 ("Image transfer function", "image_transfer_function", 
                  ["Linear", "Logarithmic", "Square-root"]),
                 ("Color palette", "color_map", 
-                 sorted(matplotlib.cm.cmap_d.keys(), key=lambda x: x.lower()))
+                 sorted(plt.colormaps(), key=lambda x: x.lower()))
         )):
             top_layout.addWidget(QLabel(label, self), row, 0)
             w = QComboBox(self)
@@ -735,7 +744,7 @@ class BeamWidget(QWidget):
         self.contours = QCheckBox("Plot contours", self)
         top_layout.addWidget(self.contours, row + 1, 0)
         self.contour_colors = QComboBox(self)
-        self.contour_colors.addItems(sorted(matplotlib.cm.cmap_d.keys(), 
+        self.contour_colors.addItems(sorted(plt.colormaps(), 
                                             key=lambda x: x.lower()))
         self.contour_colors.setCurrentText("Spectral")
         top_layout.addWidget(self.contour_colors, row + 1, 1)
@@ -1310,7 +1319,9 @@ class MainWidget(QWidget):
             # (cannot find the documentation on meaning of the axes)
             beam = np.flip(beam.T, 0)
 
-            image = axis.pcolormesh(x, y, beam, cmap=self.beam.get_color_map())
+            image = axis.pcolormesh(x, y, beam,
+                                    cmap=self.beam.get_color_map(),
+                                    shading="auto")
             color_bar = figure.colorbar(image, ax=axis)
             if self.beam.get_contours():
                 # levels copied from SCHED
